==> kubernetes-model-core-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/AzureFilePersistentVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class AzureFilePersistentVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.AzureFilePersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.AzureFilePersistentVolumeSourceFluent<A>{
  public AzureFilePersistentVolumeSourceFluentImpl() {
  }
  public AzureFilePersistentVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.AzureFilePersistentVolumeSource instance) {
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretName(instance.getSecretName()); 
    this.withSecretNamespace(instance.getSecretNamespace()); 
    this.withShareName(instance.getShareName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean readOnly;
  private java.lang.String secretName;
  private java.lang.String secretNamespace;
  private java.lang.String shareName;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getReadOnly() {
    return this.readOnly;
  }
  public A withReadOnly(java.lang.Boolean readOnly) {
    this.readOnly=readOnly; return (A) this;
  }
  public java.lang.Boolean hasReadOnly() {
    return this.readOnly != null;
  }
  public java.lang.String getSecretName() {
    return this.secretName;
  }
  public A withSecretName(java.lang.String secretName) {
    this.secretName=secretName; return (A) this;
  }
  public java.lang.Boolean hasSecretName() {
    return this.secretName != null;
  }
  
  /**
   * Method is deprecated. use withSecretName instead.
   */
  @java.lang.Deprecated
  public A withNewSecretName(java.lang.String arg0) {
    return (A)withSecretName(new String(arg0));
  }
  public java.lang.String getSecretNamespace() {
    return this.secretNamespace;
  }
  public A withSecretNamespace(java.lang.String secretNamespace) {
    this.secretNamespace=secretNamespace; return (A) this;
  }
  public java.lang.Boolean hasSecretNamespace() {
    return this.secretNamespace != null;
  }
  
  /**
   * Method is deprecated. use withSecretNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewSecretNamespace(java.lang.String arg0) {
    return (A)withSecretNamespace(new String(arg0));
  }
  public java.lang.String getShareName() {
    return this.shareName;
  }
  public A withShareName(java.lang.String shareName) {
    this.shareName=shareName; return (A) this;
  }
  public java.lang.Boolean hasShareName() {
    return this.shareName != null;
  }
  
  /**
   * Method is deprecated. use withShareName instead.
   */
  @java.lang.Deprecated
  public A withNewShareName(java.lang.String arg0) {
    return (A)withShareName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AzureFilePersistentVolumeSourceFluentImpl that = (AzureFilePersistentVolumeSourceFluentImpl) o;
    if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
    if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
    if (secretNamespace != null ? !secretNamespace.equals(that.secretNamespace) :that.secretNamespace != null) return false;
    if (shareName != null ? !shareName.equals(that.shareName) :that.shareName != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(readOnly,  secretName,  secretNamespace,  shareName,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/AzureFilePersistentVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class AzureFilePersistentVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.AzureFilePersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.AzureFilePersistentVolumeSourceFluent<A>{
  public AzureFilePersistentVolumeSourceFluentImpl() {
  }
  public AzureFilePersistentVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.AzureFilePersistentVolumeSource instance) {
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretName(instance.getSecretName()); 
    this.withSecretNamespace(instance.getSecretNamespace()); 
    this.withShareName(instance.getShareName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean readOnly;
  private java.lang.String secretName;
  private java.lang.String secretNamespace;
  private java.lang.String shareName;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getReadOnly() {
    return this.readOnly;
  }
  public A withReadOnly(java.lang.Boolean readOnly) {
    this.readOnly=readOnly; return (A) this;
  }
  public java.lang.Boolean hasReadOnly() {
    return this.readOnly != null;
  }
  public java.lang.String getSecretName() {
    return this.secretName;
  }
  public A withSecretName(java.lang.String secretName) {
    this.secretName=secretName; return (A) this;
  }
  public java.lang.Boolean hasSecretName() {
    return this.secretName != null;
  }
  
  /**
   * Method is deprecated. use withSecretName instead.
   */
  @java.lang.Deprecated
  public A withNewSecretName(java.lang.String arg0) {
    return (A)withSecretName(new String(arg0));
  }
  public java.lang.String getSecretNamespace() {
    return this.secretNamespace;
  }
  public A withSecretNamespace(java.lang.String secretNamespace) {
    this.secretNamespace=secretNamespace; return (A) this;
  }
  public java.lang.Boolean hasSecretNamespace() {
    return this.secretNamespace != null;
  }
  
  /**
   * Method is deprecated. use withSecretNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewSecretNamespace(java.lang.String arg0) {
    return (A)withSecretNamespace(new String(arg0));
  }
  public java.lang.String getShareName() {
    return this.shareName;
  }
  public A withShareName(java.lang.String shareName) {
    this.shareName=shareName; return (A) this;
  }
  public java.lang.Boolean hasShareName() {
    return this.shareName != null;
  }
  
  /**
   * Method is deprecated. use withShareName instead.
   */
  @java.lang.Deprecated
  public A withNewShareName(java.lang.String arg0) {
    return (A)withShareName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AzureFilePersistentVolumeSourceFluentImpl that = (AzureFilePersistentVolumeSourceFluentImpl) o;
    if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
    if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
    if (secretNamespace != null ? !secretNamespace.equals(that.secretNamespace) :that.secretNamespace != null) return false;
    if (shareName != null ? !shareName.equals(that.shareName) :that.shareName != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(readOnly,  secretName,  secretNamespace,  shareName,  additionalProperties,  super.hashCode());
  }
  
}
